@@ -3,11 +3,11 @@ BEGIN {
   $App::Pocoirc::AUTHORITY = 'cpan:HINRIK';
 }
 BEGIN {
-  $App::Pocoirc::VERSION = '0.14';
+  $App::Pocoirc::VERSION = '0.15';
 }
 
 use strict;
-use warnings;
+use warnings FATAL => 'all';
 
 # we want instant child process reaping
 sub POE::Kernel::USE_SIGCHLD () { return 1 }
@@ -44,6 +44,7 @@ sub run {
                 _start
                 sig_die
                 sig_int
+                sig_term
                 irc_connected
                 irc_disconnected
                 irc_snotice
@@ -126,6 +127,7 @@ sub _start {
 
     $kernel->sig(DIE => 'sig_die');
     $kernel->sig(INT => 'sig_int');
+    $kernel->sig(TERM => 'sig_term');
     $self->_status("Started");
 
     # construct global plugins
@@ -430,7 +432,7 @@ sub sig_die {
     );
 
     $self->_status($_, undef, 1) for @errors;
-    $self->_shutdown('Caught exception');
+    $self->_shutdown('Caught exception, exiting...');
     $kernel->sig_handled();
     return;
 }
@@ -438,8 +440,17 @@ sub sig_die {
 sub sig_int {
     my ($kernel, $self) = @_[KERNEL, OBJECT];
 
-    $self->_status('Caught interrupt signal, exiting...');
-    $self->_shutdown('Caught interrupt');
+    $self->_status('Caught SIGINT, exiting...');
+    $self->_shutdown('Caught SIGINT, exiting...');
+    $kernel->sig_handled();
+    return;
+}
+
+sub sig_term {
+    my ($kernel, $self) = @_[KERNEL, OBJECT];
+
+    $self->_status('Caught SIGTERM, exiting...');
+    $self->_shutdown('Caught SIGTERM, exiting...');
     $kernel->sig_handled();
     return;
 }
